//--------------------------------------------------
// Imports
//--------------------------------------------------
import test from 'ava';

import Enum from '../src/enum';

//--------------------------------------------------
// Tests
//--------------------------------------------------
test('throws when arguments are not string', t => {
  t.throws(() => Enum(1));
  t.throws(() => Enum('string', 1));
  t.notThrows(() => Enum('string1', 'string2'));
});

test('enum has all properties', t => {
  const testEnum = Enum('one', 'two', 'three');
  t.truthy(testEnum.one);
  t.truthy(testEnum.two);
  t.truthy(testEnum.three);
  t.falsy(testEnum.four);
});

test('cannot have duplicate enum properties', t => {
  t.throws(() => Enum('same', 'same'));
  t.notThrows(() => Enum('same', 'different'));
});

test('enum properties instanceof enum', t => {
  const testEnum = Enum('test');
  t.truthy(testEnum.test instanceof testEnum);
});

test('enum properties are not the same across enums', t => {
  const enum1 = Enum('test');
  const enum2 = Enum('test');
  t.not(enum1.test, enum2.test);
});

test('enum can add properties', t => {
  const enum1 = Enum('1', '2', '3');
  enum1.add('test');

  t.true(enum1.test instanceof enum1);
});
